#
# spec file for package python-ansi2html
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-ansi2html
Version:        1.9.2
Release:        1.3
Summary:        Python module to convert text with ANSI color codes to HTML or LaTeX
License:        LGPL-3.0-or-later
Group:          Development/Languages/Python
URL:            https://github.com/pycontribs/ansi2html/
Source:         https://github.com/pycontribs/ansi2html/archive/v%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Convert text with ANSI color codes to HTML or to LaTeX.

Inspired by and developed off of the work of pixelbeat and blackjack.

Read the [docs](https://ansi2html.readthedocs.io/) for more informations.

%prep
%setup -q -n ansi2html-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/ansi2html

%check
# https://github.com/pycontribs/ansi2html/issues/169
sed -i 's:from mock:from unittest.mock:' tests/test_ansi2html.py
# ansi2html not available (update alternatives); solvable
# but it runs just ansi2html --version
%pytest -k 'not test_command_script'

%post
%python_install_alternative ansi2html

%postun
%python_uninstall_alternative ansi2html

%files %{python_files}
%license LICENSE
%doc README.md
%python_alternative %{_bindir}/ansi2html
%{python_sitelib}/ansi2html/
%{python_sitelib}/ansi2html-*.dist-info/

%changelog
* Sun Jun 23 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 1.9.2:
  * github.com/psf/black.git: 24.1.1 → 24.4.2
    <https://github.com/psf/black.git/compare/24.1.1...24.4.2>
  * github.com/pre-commit/pre-commit-hooks.git: v4.5.0 → v4.6.0
    <https://github.com/pre-commit/pre-commit-hooks.git/compare/v4.5.0...v4.6.0>
  * github.com/pycqa/pylint: v3.0.3 → v3.2.2
    <https://github.com/pycqa/pylint/compare/v3.0.3...v3.2.2>
  * github.com/pre-commit/mirrors-mypy: v1.8.0 → v1.10.0
    <https://github.com/pre-commit/mirrors-mypy/compare/v1.8.0...v1.10.0>
* Wed Dec 13 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 1.9.1 (skipping non-existent release 1.9.0):
  * Bugfixes
  - Enable testing with py312 (#230) @ssbarnea
  - Fix project description (#229) @ssbarnea
  - Fix RTD builds (#228) @ssbarnea
  - tests/test_ansi2html.py: use sys.executable instead of
    hardcoded python3 (#214) @johanneskastl
  - Replace optparse with argparse (#205) @ssbarnea
  - Replace sphinx with mkdocs (#204) @ssbarnea
- remove patch
  0001-tests-test_ansi2html.py-use-sys.executable-instead-o.patch
- change upstream to pycontribs/ansi2html
* Tue May  9 2023 Johannes Kastl <kastl@b1-systems.de>
- add patch
  0001-tests-test_ansi2html.py-use-sys.executable-instead-o.patch
  to replace a hardcoded 'python3' in a test (which leads to errors
  on SLES15 with python3.11)
  https://github.com/pycontribs/ansi2html/issues/210
* Tue May  9 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Thu Aug  4 2022 Otto Hollmann <otto.hollmann@suse.com>
- Update to 1.8.0:
  * Fix for ANSI color codes that include blank values (#178)
  * style.py: Drop unused CSS class .bold (#161)
  * Added py.typed file (#176)
  * style.py: Get CSS class .inv_foreground in sync with .body_foreground (#160)
  * Fix --input-encoding=<encoding> regression added in PR #143 + related tests (alternative to PR #162) (#172)
  * Migrate from mock to unittest.mock of Python >=3.3 (fixes #169) (#171)
  * Add ability to also recognize colons in ANSI escapes (#167)
  * Fixes to respect bright colors in palette (#126)
  * CHANGELOG.rst: Fix misleading 1.6.0 entry and missing 1.7.0 entries (#159)
  * Add comments to reduce reader research time (#158)
* Wed Apr 27 2022 pgajdos@suse.com
- version update to 1.7.0
  1.7.0
  - ----
  Minor Changes
  ^^^^^^^^^^^^^
  * Replace recommendation of using system packages with pip3  @ssbarnea
  * Add truecolor support  @miltolstoy
  * Generate documentation with Sphinx and use Read the Docs  @tristanlatr
  * Adds support for OSC hyperlink sequences.  @hakonhagland
  Bugfixes
  ^^^^^^^^
  * Add test coverage  @ziegenberg
  * Replace pkg_resources with importlib.metadata  @ziegenberg
  * fix including of CHANGELOG.rst  @ziegenberg
  * Update linting dependencies  @ziegenberg
  * Upgrade the build process  @ziegenberg
  * Add type hinting  @ziegenberg
  * Update CI badges in readme  @ssbarnea
  * Bump setuptools-scm version  @ssbarnea
  1.6.0
  - ----
  Changes
  ^^^^^^^
  * Switching from nosetest to unittest  @paolostivanin
  * Add dracula colorscheme  @ahmubashshir
  * Refactor packaging by replacing old setup.py based packaging with modern pep517 based one
  * Replace travis with github actions  @ssbarnea
  Bugfixes
  ^^^^^^^^
  * Correct author metadata  @ssbarnea
  Deprecations
  ^^^^^^^^^^^^
  * Officialy retire support for python <= 3.6  @ssbarnea
- deleted patches
  - remove_nose.patch (upstreamed)
* Thu Mar 26 2020 Paolo Stivanin <info@paolostivanin.com>
- Add remove_nose.patch
* Fri Feb 15 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in descriptions.
* Thu Feb 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.5.2 release:
  * Many various drawing fixes
  * Css parsing improvements
- Sort out with spec-cleaner
- Enable tests
* Tue Oct 24 2017 rolf@rotkraut.de
- Initial version
